# Contributing to django-dto-attrs

Welcome! We're happy to have you here. Thank you in advance for your contribution to django-dto-attrs.

## Basics

django-dto-attrs welcomes contributions in the form of pull requests.

### Prerequisites

- Fork this project in GitHub and clone it,
- [install `rye`](https://rye.astral.sh/guide/installation/),
- create a `.venv` with `rye sync`.

### Development

- Add/change/remove production and test code,
- run `rye run precommit`,
- push changes to your GitHub repo fork,
- create PR.

## Releases

- `rye run release`,
- input [PyPi flango-dev account access token](https://rye.astral.sh/guide/publish/).
